==> accountbook-3.0b1.tar.gz: accountbook-3.0b1/public/sendpass2.rb <==
#!/home/netsphere/bin/ruby
# -*- coding:utf-8 -*-

# Q's Account Book
# Copyright (c) 2002 HORIKAWA Hisashi. All rights reserved.
#   mailto:vzw00011@nifty.ne.jp
#   http://www.nslabs.jp/

require "pcview.rb"

class Form < PCView
  def format_mail(ary, pwd_list)
    raise TypeError if !ary.is_a?(Array)

    header = {"From" => FROM_ADDR,
              "To" => ary.first.email,
              "MIME-Version" => "1.0",
              "Content-Type" => "text/plain; charset=ISO-2022-JP",
              "Subject" => "#{SITE_NAME}: ■　パスワード再発行　■",
              "Reply-To" => ADMIN_ADDR }

    mailbody = <<EOF
■　パスワード再発行　■

「#{SITE_NAME}」のユーザIDとパスワードをお送りします。
パスワードの変更は、ログイン後、設定「パスワード変更」でできます。

EOF
    ary.each {|ent|
      mailbody << <<EOF
ユーザID：  #{ent.login}
パスワード：#{pwd_list[ent.login]}

EOF
    }
    mailbody << <<EOF
-----------------------------------------------------------
#{SITE_NAME}：#{SITE_URL}
お問い合わせ先：mailto:#{ADMIN_ADDR}
EOF
    return [header, mailbody]
  end

  def main()
    header_out(nil, "パスワード再発行")

    mail = cgi["mail"].first
    if !mail || mail.strip == "" || !valid_mail_addr(mail)
      print "<p>不正なメールアドレスです。\n"
      footer_out(nil)
      exit
    end

    found = User.find(:all, :conditions => ["email = ?", mail])
    if found.size > 0
      pwd_list = {}
      found.each {|ent|
        pwd_list[ent.login] = [[rand(2 ** 32), rand(2 ** 32)].pack("L*")].pack("m")[0..7]
        ent.set_password(pwd_list[ent.login])
        ent.save!
      }
      send_mail(*format_mail(found, pwd_list))
    end

    print <<EOF
<p>ユーザーID，パスワードを送信しました。しばらくしてもメールが届かない場合は，登録されていないか，メールアドレスが違います。
<p><a href="./">[トップページ]</a>
EOF
    footer_out(nil)
  end
end

Form.new({"session_type" => "none"}).run

==> accountbook-3.0.0.tar.gz: accountbook-3.0.0/public/sendpass2.rb <==
#!/home/netsphere/bin/ruby
# -*- coding:utf-8 -*-

# Q's Account Book
# Copyright (c) 2002 HORIKAWA Hisashi. All rights reserved.
#   mailto:vzw00011@nifty.ne.jp
#   http://www.nslabs.jp/

require "pcview.rb"

class Form < PCView
  def format_mail(ary, pwd_list)
    raise TypeError if !ary.is_a?(Array)

    header = {"From" => FROM_ADDR,
              "To" => ary.first.email,
              "MIME-Version" => "1.0",
              "Content-Type" => "text/plain; charset=ISO-2022-JP",
              "Subject" => "#{SITE_NAME}: ■　パスワード再発行　■",
              "Reply-To" => ADMIN_ADDR }

    mailbody = <<EOF
■　パスワード再発行　■

「#{SITE_NAME}」のユーザIDとパスワードをお送りします。
パスワードの変更は、ログイン後、設定「パスワード変更」でできます。

EOF
    ary.each {|ent|
      mailbody << <<EOF
ユーザID：  #{ent.login}
パスワード：#{pwd_list[ent.login]}

EOF
    }
    mailbody << <<EOF
-----------------------------------------------------------
#{SITE_NAME}：#{SITE_URL}
お問い合わせ先：mailto:#{ADMIN_ADDR}
EOF
    return [header, mailbody]
  end

  def main()
    header_out(nil, "パスワード再発行")

    mail = cgi["mail"].first
    if !mail || mail.strip == "" || !valid_mail_addr(mail)
      print "<p>不正なメールアドレスです。\n"
      footer_out(nil)
      exit
    end

    found = User.find(:all, :conditions => ["email = ?", mail])
    if found.size > 0
      pwd_list = {}
      found.each {|ent|
        pwd_list[ent.login] = [[rand(2 ** 32), rand(2 ** 32)].pack("L*")].pack("m")[0..7]
        ent.set_password(pwd_list[ent.login])
        ent.save!
      }
      send_mail(*format_mail(found, pwd_list))
    end

    print <<EOF
<p>ユーザーID，パスワードを送信しました。しばらくしてもメールが届かない場合は，登録されていないか，メールアドレスが違います。

<p><a href="./">[シンプルWeb家計簿 Home]</a>
EOF
    footer_out(nil)
  end
end

Form.new({"session_type" => "none"}).run
